==> owncloud-10.2.0.zip: owncloud/settings/l10n/lb.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Falscht Passwuert",
    "No user supplied" : "Kee Benotzer ugebueden",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Unable to change password" : "Konnt Passwuert net änneren",
    "Couldn't send reset email. Please contact your administrator." : "D'Email fir zeréck ze setzen konnt net geschéckt ginn. W.e.g. kontaktéier däin Administrateur.",
    "A problem occurred, please check your log files (Error: %s)" : "Et ass e Problem opgetrueden, w.e.g kuckt är Log Fichieren (Feeler: %s)",
    "Migration Completed" : "D'Migratioun ass erfëllt",
    "Group already exists." : "D'Grupp existéiert schonn",
    "Unable to add group." : "Onmeiglech fir d'Grupp beizefügen.",
    "Unable to delete group." : "Onmeiglech d'Grupp ze läschen.",
    "log-level out of allowed range" : "Log-Level ass ausserhalb vum erlaabte Beräich",
    "Saved" : "Gespäichert",
    "test email settings" : "Test Email Astellungen",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Während dem Schécke vun der Email ass e Problem opgetrueden. W.e.g kuckt är Astellungen no. (Feeler: %s)",
    "Email sent" : "Email geschéckt",
    "You need to set your user email before being able to send test emails." : "Du muss deng Email-Adress konfiguréieren éiers de Test-Maile schécke kanns.",
    "Invalid mail address" : "Ongëlteg Email Adress",
    "A user with that name already exists." : "E Benotzer mat dësem Numm existéiert schonn.",
    "Unable to create user." : "Onméiglech de Benotzer ze erschafen.",
    "Your %s account was created" : "Däin %s Kont gouf erschaf",
    "Unable to delete user." : "Onmeiglech fir de User zu läschen.",
    "Forbidden" : "Net erlaabt",
    "Invalid user" : "Ongëltege Benotzer",
    "Unable to change mail address" : "Onméiglech d'Email Adress ze änneren.",
    "Your full name has been changed." : "Äre ganzen Numm ass geännert ginn.",
    "Unable to change full name" : "Onméiglech de ganzen Numm ze änneren.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "Sprooch huet geännert",
    "Invalid request" : "Ongülteg Requête",
    "Admins can't remove themself from the admin group" : "Admins kennen sech selwer net aus enger Admin Group läschen.",
    "Couldn't remove app." : "D'App konnt net ewechgeholl ginn.",
    "Official" : "Offiziell",
    "Approved" : "Accordéiert",
    "All" : "All",
    "Enabled" : "Aktivéiert",
    "Not enabled" : "Net aktivéiert",
    "No apps found for your version" : "Et gouf keng App fir deng Versioun fonnt",
    "The app will be downloaded from the app store" : "D'App gëtt aus dem App Buttek erofgelueden",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Dës App ass net op Sécherheets Problemer getest ginn an ass nei oder bekannt fir onstabil ze sinn. Installéieren op eegene Risiko.",
    "Please wait...." : "W.e.g. waarden...",
    "Error while disabling app" : "Feeler beim App ofschalten",
    "Disable" : "Ofschalten",
    "Enable" : "Aschalten",
    "Error while enabling app" : "Feeler beim App aschalten",
    "Error: this app cannot be enabled because it makes the server unstable" : "Feeler: Dës App kann net ageschalt ginn well et de Server onstabil mécht",
    "Error: could not disable broken app" : "Feeler: déi futti's App kann net ofgeschalt ginn",
    "Error while disabling broken app" : "Feller beim Ofschalte vun der futtisser App",
    "Updating...." : "Aktualiséieren...",
    "Error while updating app" : "Feeler beim Aktualiséiere vun der App",
    "Updated" : "Aktualiséiert",
    "Uninstalling ...." : "Gëtt desinstalléiert ...",
    "Error while uninstalling app" : "Feeler beim App desinstalléieren",
    "Uninstall" : "Desinstalléieren",
    "App update" : "App Aktualiséierung",
    "Experimental" : "Experimentell",
    "No apps found for {query}" : "Keng Apps fonnt fir {Ufro}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Bas du wierklech sécher dass de \"{Domän}\" als zouverlässeg Domän derbäi setzen wëlls?",
    "Add trusted domain" : "Zouverlässeg Domän derbäi setzen",
    "Migration in progress. Please wait until the migration is finished" : "D'Migratioun ass am gaangen. W.e.g waart bis d'Migratioun fäerdeg ass",
    "Migration started …" : "D'Migratioun fänkt un ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Et ass e Feeler opgetrueden. W.e.g. luet een ASCII-encodéierte PEM Zertifikat erop.",
    "Valid until {date}" : "Gülteg bis {Datum}",
    "Delete" : "Läschen",
    "Disconnect" : "Trennen",
    "Error while loading browser sessions and device tokens" : "Feeler während d'Browser Sëtzunge an d'Token Geräter gelueden hunn",
    "Error while creating device token" : "Feeler beim Erstelle vum Token Gerät",
    "Error while deleting the token" : "Feeler beim Läsche vum Token",
    "Sending..." : "Gëtt geschéckt...",
    "An error occurred: {message}" : "Et ass e Fehler opgetrueden: {Noriicht}",
    "Select a profile picture" : "Wiel e Profil Bild aus",
    "Very weak password" : "Ganz schwaacht Passwuert",
    "Weak password" : "Schwaacht Passwuert",
    "So-so password" : "La-La Passwuert",
    "Good password" : "Gutt Passwuert",
    "Strong password" : "Staarkt Passwuert",
    "Groups" : "Gruppen",
    "Unable to delete {objName}" : "Onmeiglech fir {objName} ze läschen",
    "Error creating group: {message}" : "Feeler beim Erstelle vun der Grupp: {Noriicht}",
    "A valid group name must be provided" : "Et muss e gültege Gruppen Numm ugi ginn",
    "deleted {groupName}" : "Geläscht {GruppenNumm}",
    "undo" : "Réckgängeg man",
    "never" : "Ni",
    "deleted {userName}" : "Geläscht  {Benotzernumm}",
    "add group" : "Grupp bäisetzen",
    "no group" : "Keng Grupp",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "D'Passwuert ännere wäert e Verloscht vun den Daten provozéiere, well Daten zeréck gewannen ass net disponibel fir dëse Benotzer",
    "A valid username must be provided" : "Et muss e gültegen Benotzernumm ugi ginn",
    "Error creating user: {message}" : "Feeler beim Erstelle vum Benotzer: {Noriicht}",
    "A valid password must be provided" : "Et muss e gültegt Passwuert ugi ginn",
    "A valid email must be provided" : "Et muss eng gülteg Emails Adresse ugi ginn",
    "Cheers!" : "Prost!",
    "User documentation" : "Benotzer Dokumentatioun",
    "Administrator documentation" : "Administrator Dokumentatioun",
    "Online documentation" : "Online Dokumentatioun",
    "Forum" : "Forum",
    "Issue tracker" : "Aspekter Tracker",
    "Commercial support" : "Kommerziell Ennerstëtzung",
    "Developer documentation" : "Entwéckler Dokumentatioun",
    "by %s" : "vum %s",
    "%s-licensed" : "%s-lizenséiert",
    "Documentation:" : "Dokumentatioun:",
    "Admin documentation" : "Admin Dokumentatioun",
    "Visit website" : "D'Websäit besichen",
    "Report a bug" : "E Feeler melden",
    "Show description …" : "D'Beschreiwung weisen",
    "Hide description …" : "D'Beschreiwung verstoppe",
    "Enable only for specific groups" : "Nëmme fir spezifesch Gruppen aschalten",
    "Uninstall App" : "D'App desinstalléieren",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Leschte Cron Job Ausféierung: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Leschte Cron Job Ausféierung: %s. Eppes schéngt net ze klappen.",
    "Cron was not executed yet!" : "Cron ass nach net ausgefouert ginn!",
    "Open documentation" : "Dokumentatioun opmaachen",
    "Execute one task with each page loaded" : "Mat all geluedener Säit eng Aufgab ausféieren",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php ass als webcron Service registréiert fir cron.php all15 Minutten iwwer http opzeruffen.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Dem System säi Cron Service benotze fir d'Cron.php Fichieren all 15 Minutten opzeruffen.",
    "SSL Root Certificates" : "SSL Wuerzel Zertifikat",
    "Common Name" : "Allgemengen Numm",
    "Valid until" : "Gülteg bis",
    "Issued By" : "Ausgestallt vum",
    "Valid until %s" : "Gülteg bis %s",
    "Import root certificate" : "Wuerzel Zertifikat importéieren",
    "Server-side encryption" : "Verschlësselung vun der Säit vum Server",
    "Enable server-side encryption" : "Verschlësselung vun der Säit vum Server erlaaben",
    "Please read carefully before activating server-side encryption: " : "W.e.g. lies opmierksam éier d'Verschlësselung vun der Säit vum Server aktivéiert gëtt:",
    "Be aware that encryption always increases the file size." : "Sief der bewosst dass Verschlësselung ëmmer d'Gréisst vum Fichier erhéicht.",
    "This is the final warning: Do you really want to enable encryption?" : "Dëst ass déi lescht Warnung: Wëlls de wierklech d'Verschlësselung aschalten?",
    "Enable encryption" : "Verschlësselung aschalten",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Kee Verschlësselungs Modul gelueden, w.e.g. schalt en Verschlësselungs Modul am App Menü an.",
    "Select default encryption module:" : "Standard Verschlësselung Modul auswielen:",
    "Start migration" : "Migratioun ufänke",
    "Sharing" : "Gedeelt",
    "Allow apps to use the Share API" : "Erlab Apps d'Share API ze benotzen",
    "Allow users to share via link" : "De Benotzer d'Deele via Link erlaben",
    "Allow public uploads" : "Ëffentlechen Upload erlaaben",
    "Enforce password protection" : "Passwuert Schutz forcéieren",
    "Set default expiration date" : "E Standard Verfallsdatum setzen",
    "Allow users to send mail notification for shared files" : "De Benotzer erlaben Email Notifikatiounen fir gedeelten Fichieren ze schécken",
    "Expire after " : "Oflafen nom",
    "days" : "Deeg",
    "Enforce expiration date" : "Verfallsdatum forcéieren",
    "Allow resharing" : "Resharing erlaben",
    "Allow sharing with groups" : "Deele mat Gruppen erlaben",
    "Restrict users to only share with users in their groups" : "Benotzer aschränken fir nëmmen mat Benotzer aus hirerem Grupp ze deelen",
    "Exclude groups from sharing" : "Gruppe vum Deelen ausschléissen",
    "These groups will still be able to receive shares, but not to initiate them." : "Dës Gruppe kënnen weiderhin Undeeler kréien, mee kënnen se net ufänken.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatal Aspekter, Feeler, Warnungen, Informatiounen, Debug)",
    "Info, warnings, errors and fatal issues" : " Informatiounen, Warnungen, Feeler a fatal Aspekter",
    "Warnings, errors and fatal issues" : "Warnungen, Feeler a fatal Aspekter",
    "Errors and fatal issues" : "Feeler a fatal Aspekter",
    "Fatal issues only" : "Nëmmen fatal Aspekter",
    "Log" : "Log",
    "What to log" : "Wat loggen",
    "None" : "Keng",
    "Login" : "Login",
    "Plain" : "Kloer",
    "Email server" : "Email Server",
    "This is used for sending out notifications." : "Dëst gëtt benotzt fir Notifikatiounen eraus ze schécken.",
    "Send mode" : "Verschécke-Modus",
    "Encryption" : "Verschlësselung",
    "From address" : "Vun der Adresse",
    "mail" : "Mail",
    "Authentication method" : "Authentifizéierungs Method",
    "Authentication required" : "Authentifizéierung néideg",
    "Server address" : "Server Adress",
    "Port" : "Port",
    "SMTP Username" : "SMTP Benotzernumm",
    "SMTP Password" : "SMTP Passwuert",
    "Test email settings" : "Email Astellungen testen",
    "Send email" : "Email schécken",
    "Security & setup warnings" : "Sécherheets & Konfiguratiouns Warnung",
    "This means that there might be problems with certain characters in file names." : "Dëst heescht dass Problemer mat bestëmmte Charaktere bei de Fichier Nimm optauche kéinten.",
    "All checks passed." : "All d'Tester bestanen.",
    "Tips & tricks" : "Tipps & Tricken",
    "How to do backups" : "Wéi ee Backup'e mécht",
    "Advanced monitoring" : "Erweidert Beobachtung",
    "Performance tuning" : "Leeschtungs Optimiséierung",
    "Improving the config.php" : "D'Verbesseren vum config.php",
    "Get the apps to sync your files" : "D'Apps op Fichieren syncen",
    "Desktop client" : "Desktop Client",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Profile picture" : "Profil Foto",
    "Upload new" : "Nei eroplueden",
    "Select from Files" : "Aus de Fichieren wielen",
    "Remove image" : "D'Bild läschen",
    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
    "Picture provided by original account" : "Bild vum Original Kont bereet gestallt",
    "Cancel" : "Ofbriechen",
    "Choose as profile picture" : "Als Profil Foto auswielen",
    "Full name" : "Ganzen Numm",
    "No display name set" : "Keen Nickname festgesat",
    "Email" : "Email",
    "Your email address" : "Deng Email Adress",
    "For password recovery and notifications" : "Fir d'Passwuert zeréck ze setzen an Notifikatiounen",
    "Password" : "Passwuert",
    "Unable to change your password" : "Konnt däin Passwuert net änneren",
    "Current password" : "Momentan 't Passwuert",
    "New password" : "Neit Passwuert",
    "Change password" : "Passwuert änneren",
    "Language" : "Sprooch",
    "Help translate" : "Hëllef iwwersetzen",
    "Unlimited" : "Onlimitéiert",
    "Sessions" : "Sëtzung",
    "Browser" : "Browser",
    "Most recent activity" : "Rezentsten Aktivitéit",
    "App passwords" : "App Passwierder",
    "You've linked these apps." : "Du hues dës Apps verbonnen",
    "Name" : "Numm",
    "App name" : "App Numm",
    "Create new app password" : "En neit App Passwuert erstellen",
    "Username" : "Benotzernumm",
    "Done" : "Gemaacht",
    "Version" : "Versioun",
    "Personal" : "Perséinlech",
    "Admin" : "Admin",
    "Error" : "Feeler",
    "Show storage location" : "Weis de Lagerungs Uert un",
    "Show last log in" : "Leschte Login uweisen",
    "Show user backend" : "Backend  Benotzer uweisen",
    "Send email to new user" : "Eng Email un d'nei Benotzer schécken",
    "Show email address" : "Emails Adress uweisen",
    "E-Mail" : "E-Mail",
    "Create" : "Erstellen",
    "Admin Recovery Password" : "Admin Passwuert zeréck stellen",
    "Add Group" : "Grupp bäisetzen",
    "Group" : "Grupp",
    "Everyone" : "Jiddereen",
    "Admins" : "Admin",
    "Default Quota" : "Standard Quota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "W.e.g. gëff Quota vum Lagerungs Uert un (wx. \"512 MB\" oder \"12 GB\")",
    "Other" : "Aner",
    "Full Name" : "Ganzen Numm",
    "Group Admin for" : "Gruppen Admin fir",
    "Quota" : "Quota",
    "Storage Location" : "Lagerungs Uert",
    "User Backend" : "Backend Benotzer",
    "Last Login" : "Lëschte Login",
    "change full name" : "Ganzen Numm änneren",
    "set new password" : "Neit Passwuert setzen",
    "change email address" : "Emails Adress wiesselen",
    "Default" : "Standard",
    "Share" : "Deelen",
    "Add" : "Dobäisetzen",
    "Users" : "Benotzer"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/lb.js <==
OC.L10N.register(
    "settings",
    {
    "No user supplied" : "Kee Benotzer ugebueden",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Unable to change password" : "Konnt Passwuert net änneren",
    "Couldn't send reset email. Please contact your administrator." : "D'Email fir zeréck ze setzen konnt net geschéckt ginn. W.e.g. kontaktéier däin Administrateur.",
    "Group already exists." : "D'Grupp existéiert schonn",
    "Unable to add group." : "Onmeiglech fir d'Grupp beizefügen.",
    "Unable to delete group." : "Onmeiglech d'Grupp ze läschen.",
    "Saved" : "Gespäichert",
    "log-level out of allowed range" : "Log-Level ass ausserhalb vum erlaabte Beräich",
    "test email settings" : "Test Email Astellungen",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Während dem Schécke vun der Email ass e Problem opgetrueden. W.e.g kuckt är Astellungen no. (Feeler: %s)",
    "Email sent" : "Email geschéckt",
    "You need to set your user email before being able to send test emails." : "Du muss deng Email-Adress konfiguréieren éiers de Test-Maile schécke kanns.",
    "Your %s account was created" : "Däin %s Kont gouf erschaf",
    "Invalid mail address" : "Ongëlteg Email Adress",
    "A user with that name already exists." : "E Benotzer mat dësem Numm existéiert schonn.",
    "Unable to create user." : "Onméiglech de Benotzer ze erschafen.",
    "Unable to delete user." : "Onmeiglech fir de User zu läschen.",
    "Forbidden" : "Net erlaabt",
    "Invalid user" : "Ongëltege Benotzer",
    "Unable to change mail address" : "Onméiglech d'Email Adress ze änneren.",
    "Your full name has been changed." : "Äre ganzen Numm ass geännert ginn.",
    "Unable to change full name" : "Onméiglech de ganzen Numm ze änneren.",
    "Create" : "Erstellen",
    "Delete" : "Läschen",
    "Share" : "Deelen",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Language changed" : "Sprooch huet geännert",
    "Invalid request" : "Ongülteg Requête",
    "Admins can't remove themself from the admin group" : "Admins kennen sech selwer net aus enger Admin Group läschen.",
    "Couldn't remove app." : "D'App konnt net ewechgeholl ginn.",
    "Official" : "Offiziell",
    "Approved" : "Accordéiert",
    "All" : "All",
    "Enabled" : "Aktivéiert",
    "Not enabled" : "Net aktivéiert",
    "No apps found for your version" : "Et gouf keng App fir deng Versioun fonnt",
    "The app will be downloaded from the app store" : "D'App gëtt aus dem App Buttek erofgelueden",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Dës App ass net op Sécherheets Problemer getest ginn an ass nei oder bekannt fir onstabil ze sinn. Installéieren op eegene Risiko.",
    "Please wait...." : "W.e.g. waarden...",
    "Error while disabling app" : "Feeler beim App ofschalten",
    "Disable" : "Ofschalten",
    "Enable" : "Aschalten",
    "Error while enabling app" : "Feeler beim App aschalten",
    "Error: this app cannot be enabled because it makes the server unstable" : "Feeler: Dës App kann net ageschalt ginn well et de Server onstabil mécht",
    "Error: could not disable broken app" : "Feeler: déi futti's App kann net ofgeschalt ginn",
    "Error while disabling broken app" : "Feller beim Ofschalte vun der futtisser App",
    "Updating...." : "Aktualiséieren...",
    "Error while updating app" : "Feeler beim Aktualiséiere vun der App",
    "Updated" : "Aktualiséiert",
    "Uninstalling ...." : "Gëtt desinstalléiert ...",
    "Error while uninstalling app" : "Feeler beim App desinstalléieren",
    "Uninstall" : "Desinstalléieren",
    "App update" : "App Aktualiséierung",
    "Experimental" : "Experimentell",
    "No apps found for {query}" : "Keng Apps fonnt fir {Ufro}",
    "Migration in progress. Please wait until the migration is finished" : "D'Migratioun ass am gaangen. W.e.g waart bis d'Migratioun fäerdeg ass",
    "Migration started …" : "D'Migratioun fänkt un ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Et ass e Feeler opgetrueden. W.e.g. luet een ASCII-encodéierte PEM Zertifikat erop.",
    "Valid until {date}" : "Gülteg bis {Datum}",
    "Disconnect" : "Trennen",
    "Error while loading browser sessions and device tokens" : "Feeler während d'Browser Sëtzunge an d'Token Geräter gelueden hunn",
    "Error while creating device token" : "Feeler beim Erstelle vum Token Gerät",
    "Error while deleting the token" : "Feeler beim Läsche vum Token",
    "Sending..." : "Gëtt geschéckt...",
    "An error occurred: {message}" : "Et ass e Fehler opgetrueden: {Noriicht}",
    "Select a profile picture" : "Wiel e Profil Bild aus",
    "Very weak password" : "Ganz schwaacht Passwuert",
    "Weak password" : "Schwaacht Passwuert",
    "So-so password" : "La-La Passwuert",
    "Good password" : "Gutt Passwuert",
    "Strong password" : "Staarkt Passwuert",
    "Groups" : "Gruppen",
    "Unable to delete {objName}" : "Onmeiglech fir {objName} ze läschen",
    "Error creating group: {message}" : "Feeler beim Erstelle vun der Grupp: {Noriicht}",
    "A valid group name must be provided" : "Et muss e gültege Gruppen Numm ugi ginn",
    "deleted {groupName}" : "Geläscht {GruppenNumm}",
    "undo" : "Réckgängeg man",
    "Delete group" : "D'Grupp läaschen",
    "never" : "Ni",
    "deleted {userName}" : "Geläscht  {Benotzernumm}",
    "add group" : "Grupp bäisetzen",
    "no group" : "Keng Grupp",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "D'Passwuert ännere wäert e Verloscht vun den Daten provozéiere, well Daten zeréck gewannen ass net disponibel fir dëse Benotzer",
    "A valid username must be provided" : "Et muss e gültegen Benotzernumm ugi ginn",
    "Error creating user: {message}" : "Feeler beim Erstelle vum Benotzer: {Noriicht}",
    "A valid password must be provided" : "Et muss e gültegt Passwuert ugi ginn",
    "A valid email must be provided" : "Et muss eng gülteg Emails Adresse ugi ginn",
    "Cheers!" : "Prost!",
    "User documentation" : "Benotzer Dokumentatioun",
    "Administrator documentation" : "Administrator Dokumentatioun",
    "Developer documentation" : "Entwéckler Dokumentatioun",
    "Online documentation" : "Online Dokumentatioun",
    "Forum" : "Forum",
    "Issue tracker" : "Aspekter Tracker",
    "Commercial support" : "Kommerziell Ennerstëtzung",
    "Language" : "Sprooch",
    "by %s" : "vum %s",
    "%s-licensed" : "%s-lizenséiert",
    "Documentation:" : "Dokumentatioun:",
    "Admin documentation" : "Admin Dokumentatioun",
    "Visit website" : "D'Websäit besichen",
    "Report a bug" : "E Feeler melden",
    "Show description …" : "D'Beschreiwung weisen",
    "Hide description …" : "D'Beschreiwung verstoppe",
    "Enable only for specific groups" : "Nëmme fir spezifesch Gruppen aschalten",
    "Uninstall App" : "D'App desinstalléieren",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Leschte Cron Job Ausféierung: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Leschte Cron Job Ausféierung: %s. Eppes schéngt net ze klappen.",
    "Cron was not executed yet!" : "Cron ass nach net ausgefouert ginn!",
    "Open documentation" : "Dokumentatioun opmaachen",
    "Execute one task with each page loaded" : "Mat all geluedener Säit eng Aufgab ausféieren",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php ass als webcron Service registréiert fir cron.php all15 Minutten iwwer http opzeruffen.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Dem System säi Cron Service benotze fir d'Cron.php Fichieren all 15 Minutten opzeruffen.",
    "SSL Root Certificates" : "SSL Wuerzel Zertifikat",
    "Common Name" : "Allgemengen Numm",
    "Valid until" : "Gülteg bis",
    "Issued By" : "Ausgestallt vum",
    "Valid until %s" : "Gülteg bis %s",
    "Import root certificate" : "Wuerzel Zertifikat importéieren",
    "Server-side encryption" : "Verschlësselung vun der Säit vum Server",
    "Enable server-side encryption" : "Verschlësselung vun der Säit vum Server erlaaben",
    "Please read carefully before activating server-side encryption: " : "W.e.g. lies opmierksam éier d'Verschlësselung vun der Säit vum Server aktivéiert gëtt:",
    "Be aware that encryption always increases the file size." : "Sief der bewosst dass Verschlësselung ëmmer d'Gréisst vum Fichier erhéicht.",
    "This is the final warning: Do you really want to enable encryption?" : "Dëst ass déi lescht Warnung: Wëlls de wierklech d'Verschlësselung aschalten?",
    "Enable encryption" : "Verschlësselung aschalten",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Kee Verschlësselungs Modul gelueden, w.e.g. schalt en Verschlësselungs Modul am App Menü an.",
    "Select default encryption module:" : "Standard Verschlësselung Modul auswielen:",
    "Start migration" : "Migratioun ufänke",
    "Sharing" : "Gedeelt",
    "Allow apps to use the Share API" : "Erlab Apps d'Share API ze benotzen",
    "Allow users to share via link" : "De Benotzer d'Deele via Link erlaben",
    "Allow public uploads" : "Ëffentlechen Upload erlaaben",
    "Set default expiration date" : "E Standard Verfallsdatum setzen",
    "Expire after " : "Oflafen nom",
    "days" : "Deeg",
    "Allow users to send mail notification for shared files" : "De Benotzer erlaben Email Notifikatiounen fir gedeelten Fichieren ze schécken",
    "Allow resharing" : "Resharing erlaben",
    "Allow sharing with groups" : "Deele mat Gruppen erlaben",
    "Restrict users to only share with users in their groups" : "Benotzer aschränken fir nëmmen mat Benotzer aus hirerem Grupp ze deelen",
    "Exclude groups from sharing" : "Gruppe vum Deelen ausschléissen",
    "These groups will still be able to receive shares, but not to initiate them." : "Dës Gruppe kënnen weiderhin Undeeler kréien, mee kënnen se net ufänken.",
    "None" : "Keng",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatal Aspekter, Feeler, Warnungen, Informatiounen, Debug)",
    "Info, warnings, errors and fatal issues" : " Informatiounen, Warnungen, Feeler a fatal Aspekter",
    "Warnings, errors and fatal issues" : "Warnungen, Feeler a fatal Aspekter",
    "Errors and fatal issues" : "Feeler a fatal Aspekter",
    "Fatal issues only" : "Nëmmen fatal Aspekter",
    "Log" : "Log",
    "What to log" : "Wat loggen",
    "Login" : "Login",
    "Plain" : "Kloer",
    "Email server" : "Email Server",
    "This is used for sending out notifications." : "Dëst gëtt benotzt fir Notifikatiounen eraus ze schécken.",
    "Send mode" : "Verschécke-Modus",
    "Encryption" : "Verschlësselung",
    "From address" : "Vun der Adresse",
    "mail" : "Mail",
    "Authentication method" : "Authentifizéierungs Method",
    "Authentication required" : "Authentifizéierung néideg",
    "Server address" : "Server Adress",
    "Port" : "Port",
    "SMTP Username" : "SMTP Benotzernumm",
    "SMTP Password" : "SMTP Passwuert",
    "Test email settings" : "Email Astellungen testen",
    "Send email" : "Email schécken",
    "Security & setup warnings" : "Sécherheets & Konfiguratiouns Warnung",
    "This means that there might be problems with certain characters in file names." : "Dëst heescht dass Problemer mat bestëmmte Charaktere bei de Fichier Nimm optauche kéinten.",
    "All checks passed." : "All d'Tester bestanen.",
    "Tips & tricks" : "Tipps & Tricken",
    "How to do backups" : "Wéi ee Backup'e mécht",
    "Performance tuning" : "Leeschtungs Optimiséierung",
    "Improving the config.php" : "D'Verbesseren vum config.php",
    "Get the apps to sync your files" : "D'Apps op Fichieren syncen",
    "Desktop client" : "Desktop Client",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Add" : "Dobäisetzen",
    "Profile picture" : "Profil Foto",
    "Upload new" : "Nei eroplueden",
    "Select from Files" : "Aus de Fichieren wielen",
    "Remove image" : "D'Bild läschen",
    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
    "Picture provided by original account" : "Bild vum Original Kont bereet gestallt",
    "Cancel" : "Ofbriechen",
    "Choose as profile picture" : "Als Profil Foto auswielen",
    "Full name" : "Ganzen Numm",
    "No display name set" : "Keen Nickname festgesat",
    "Email" : "Email",
    "Your email address" : "Deng Email Adress",
    "For password recovery and notifications" : "Fir d'Passwuert zeréck ze setzen an Notifikatiounen",
    "Password" : "Passwuert",
    "Unable to change your password" : "Konnt däin Passwuert net änneren",
    "Current password" : "Momentan 't Passwuert",
    "New password" : "Neit Passwuert",
    "Change password" : "Passwuert änneren",
    "Help translate" : "Hëllef iwwersetzen",
    "Sessions" : "Sëtzung",
    "Browser" : "Browser",
    "Most recent activity" : "Rezentsten Aktivitéit",
    "You've linked these apps." : "Du hues dës Apps verbonnen",
    "Name" : "Numm",
    "App name" : "App Numm",
    "Username" : "Benotzernumm",
    "Done" : "Gemaacht",
    "Version" : "Versioun",
    "New Password" : "Neit Passwuert",
    "Personal" : "Perséinlech",
    "Admin" : "Admin",
    "Other" : "Aner",
    "Settings" : "Astellungen",
    "Show storage location" : "Weis de Lagerungs Uert un",
    "Show last log in" : "Leschte Login uweisen",
    "Show user backend" : "Backend  Benotzer uweisen",
    "Show email address" : "Emails Adress uweisen",
    "E-Mail" : "E-Mail",
    "Admin Recovery Password" : "Admin Passwuert zeréck stellen",
    "Add Group" : "Grupp bäisetzen",
    "Group" : "Grupp",
    "Everyone" : "Jiddereen",
    "Admins" : "Admin",
    "Default Quota" : "Standard Quota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "W.e.g. gëff Quota vum Lagerungs Uert un (wx. \"512 MB\" oder \"12 GB\")",
    "Unlimited" : "Onlimitéiert",
    "Full Name" : "Ganzen Numm",
    "Group Admin for" : "Gruppen Admin fir",
    "Quota" : "Quota",
    "Storage Location" : "Lagerungs Uert",
    "User Backend" : "Backend Benotzer",
    "Last Login" : "Lëschte Login",
    "change full name" : "Ganzen Numm änneren",
    "set new password" : "Neit Passwuert setzen",
    "change email address" : "Emails Adress wiesselen",
    "Default" : "Standard"
},
"nplurals=2; plural=(n != 1);");
